@@ -2071,43 +2071,36 @@ glade_utils_get_pointer (GtkWidget *widget,
     *y = final_y;
 }
 
-/**
- * _glade_util_file_get_relative_path:
- * @target: input GFile
- * @source: input GFile
- *
- * Gets the path for @source relative to @target even if @source is not a
- * descendant of @target.
- *
+/* Use this to disable scroll events on property editors,
+ * we dont want them handling scroll because they are inside
+ * a scrolled window and interrupt workflow causing unexpected
+ * results when scrolled.
  */
-gchar *
-_glade_util_file_get_relative_path (GFile *target, GFile *source)
+static gint
+abort_scroll_events (GtkWidget *widget,
+		     GdkEvent  *event,
+		     gpointer   user_data)
 {
-  gchar *relative_path;
+  GtkWidget *parent = gtk_widget_get_parent (widget);
 
-  if ((relative_path = g_file_get_relative_path (target, source)) == NULL)
-    {
-      GString *relpath = g_string_new ("");
+  /* Removing the events from the mask doesnt work for
+   * stubborn combo boxes which call gtk_widget_add_events()
+   * in it's gtk_combo_box_init() - so handle the event and propagate
+   * it up the tree so the scrollwindow still handles the scroll event.
+   */
+  gtk_propagate_event (parent, event);
 
-      g_object_ref (target);
+  return TRUE;
+}
 
-      while (relative_path == NULL)
-        {
-          GFile *old_target = target;
-          target = g_file_get_parent (target);
+void
+glade_util_remove_scroll_events (GtkWidget *widget)
+{
+  gint events = gtk_widget_get_events (widget);
 
-          relative_path = g_file_get_relative_path (target, source);
+  events &= ~(GDK_SCROLL_MASK | GDK_SMOOTH_SCROLL_MASK);
+  gtk_widget_set_events (widget, events);
 
-          g_string_append (relpath, "..");
-          g_string_append_c (relpath, G_DIR_SEPARATOR);
-
-          g_object_unref (old_target);
-        }
-
-      g_string_append (relpath, relative_path);
-      g_free (relative_path);
-      relative_path = g_string_free (relpath, FALSE);
-    }
-
-  return relative_path;
+  g_signal_connect (G_OBJECT (widget), "scroll-event",
+		    G_CALLBACK (abort_scroll_events), NULL);
 }
